#! /usr/bin/env python
# -*- coding: utf-8 -*-

import os
import gtk
from library import MediaDB
from widget.playlist import playlist_ui
import utils
from config import config

plugin_name = "samplemusic"

def touch(filepath):
    dirname = os.path.dirname(filepath)
    if dirname and not os.path.exists(dirname):
        os.makedirs(dirname)
    with open(filepath, "a") as fp:
        fp.write("")

def has_started():
    has_started_file = os.path.expanduser("~/.config/deepin-sample-music/has_started")
    if not os.path.exists(has_started_file):
        touch(has_started_file)
        return False
    else:
        return True

def get_sample_list_uris():
    sample_dir_config = os.path.join(os.path.dirname(os.path.realpath(__file__)), "sample_dir_config")
    with open(sample_dir_config) as fp:
        sample_music_dir = fp.read().strip()

    sample_list_uris = []
    if os.path.exists(sample_music_dir):
        for root, dirs, files in os.walk(sample_music_dir):
            for f in files:
                if f.endswith(".m3u"):
                    sample_list_uris.append("file://" + os.path.join(root, f))
    return sample_list_uris

def get_exists_playlists():
    return [pl.get_name() for pl in MediaDB.get_playlists()]

def create_playlist():
    pl_uris = get_sample_list_uris()
    has_added = False
    for uri in pl_uris:
        pl_name = utils.get_filename(uri)
        if pl_name not in get_exists_playlists():
            playlist_ui.import_list_from_uri(uri)
            has_added = True
    if has_added:
        select_index = len(MediaDB.get_playlists()) - 1
        category_item = playlist_ui.get_categroy_item_by_index(select_index)
        playlist_ui.reset_highlight_item(category_item)
        config.set("playlist","current_index", str(select_index))

def delete_playlist():
    sample_pl_names = [utils.get_filename(uri) for uri in get_sample_list_uris()]
    exists_playlists = MediaDB.get_playlists()
    for index, pl in enumerate(exists_playlists):
        if pl.get_name() in sample_pl_names:
            item = playlist_ui.get_categroy_item_by_index(index)
            playlist_ui.delete_item_list(item)
            MediaDB.del_playlist("local", pl)

def enable(dmusic):
    plugins = utils.get_main_window().plugins
    if plugins.load or not has_started():
        create_playlist()

def disable(dmusic):
    delete_playlist()

